@@ -1,7 +1,21 @@
 #!/usr/bin/env bash
 set -Eeu -o pipefail
 
+# Setup env variables to be compatible with compiled and bundled installations
 CURRENT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
+RELEASE_DIR="${CURRENT_DIR}/target/release"
+
+THUMBS_BINARY="${RELEASE_DIR}/thumbs"
+TMUX_THUMBS_BINARY="${RELEASE_DIR}/tmux-thumbs"
+VERSION=$(grep 'version =' "${CURRENT_DIR}/Cargo.toml" | grep -oe "[0-9]\+.[0-9]\+.[0-9]\+")
+
+if [ ! -f "$THUMBS_BINARY" ]; then
+  tmux split-window "cd ${CURRENT_DIR} && bash ./tmux-thumbs-install.sh"
+  exit
+elif [[ $(${THUMBS_BINARY} --version) != "thumbs ${VERSION}"  ]]; then
+  tmux split-window "cd ${CURRENT_DIR} && bash ./tmux-thumbs-install.sh update"
+  exit
+fi
 
 function get-opt-value() {
   tmux show -vg "@thumbs-${1}" 2> /dev/null
@@ -36,4 +50,4 @@ add-param upcase-command string
 add-param multi-command  string
 add-param osc52          boolean
 
-"${CURRENT_DIR}/target/release/tmux-thumbs" "${PARAMS[@]}" || true
+"${TMUX_THUMBS_BINARY}" "${PARAMS[@]}" || true
